@@ -1,19 +1,18 @@
 import typer
 from typing_extensions import Annotated
 from rich import print
-from core.client import AuthenticatedPlatformClient
 from core.debug_aws_batch import DebugAWSBatch
 
+from batch_debugging_cli.gcp_batch_commands import GCPBatchCommands
 from batch_debugging_cli.aws_batch_commands import AWSBatchCommands
 
 
-authenticated_client = AuthenticatedPlatformClient()
 app = typer.Typer()
 
-debug_aws_batch = DebugAWSBatch(authenticated_client)
+debug_aws_batch = DebugAWSBatch()
 
 @app.command()
-def debugCE(compute_env_id: Annotated[str, typer.Option(prompt="Please insert a valid compute enviornment name")]):
+def debugCE(compute_env_id: Annotated[str, typer.Option(prompt="Please insert a valid compute environment name")]):
     aws_batch_commands = AWSBatchCommands(compute_env_id=compute_env_id, debug_aws_batch=debug_aws_batch)
     aws_batch_commands.debug_compute_env(compute_env_id)
 
@@ -26,5 +25,11 @@ def getLaunchTemplate(compute_env_id: str):
     print(launch_template_userdata)
 
  
+@app.command()
+def gcp_create_job(job_name: Annotated[str, typer.Option(prompt="Please insert a name for the batch job")]):
+    gcp_batch_commands = GCPBatchCommands()
+    batch_job = gcp_batch_commands.create_test_job(job_name)
+    
+ 
 if __name__ == "__main__":
     app()
\ No newline at end of file
